@@ -8,6 +8,8 @@ def theme():
     import gettext
     import locale
 
+    section="blue"
+
     # get g++ version
     gv = os.popen("g++ -dumpversion").read().strip()
 
@@ -24,26 +26,32 @@ def theme():
     enc = locale.getpreferredencoding()
     if "UTF" in enc:
         # gcc will use unicode quotes
-        qo = "‘"
-        qc = "’"
+        qo = "[‘`]"
+        qc = "[’']"
     else:
         # rather than ascii ones
-        qo = "'"
+        qo = "['`]"
         qc = "'"
 
     return [
         [ _("error: "), "red", "bold" ],
         [ _("warning: "), "magenta", "bold" ],
-        [ _("note: "), "blue", "bold" ],
+        [ _("undefined reference to "), "red", "bold" ],
         # [-Wflag]
         [ "\[-W.*\]", "magenta"],
 
         # Highlight message start:
         #   path   file   ext     : line   :  col     …
         [ "(/.*?)/([^/:]+): (In .*)"+qo,
-          "green",
+          section,
           "normal,normal,bold" ],
 
+        [ "(/.*?)/([^/:]+): (At .*)",
+          section,
+          "normal,normal,bold" ],
+
+        [ _("In file included from"), section ],
+
         # Highlight locations:
         #   path   file   ext     : line   :  col     …
         [ "(/.*?)/([^/:]+):([0-9]+):*([0-9]*)(.*)",
@@ -51,6 +59,11 @@ def theme():
           "normal,normal,normal,normal" ],
 
         # source code in single quotes
-        [ qo+"(.*?)"+qc, "Cpp", "monokai" ]
+        [ qo+"(.*?)"+qc, "Cpp", "monokai" ],
+
+        # source code after a "note: candidate are/is:"
+        [ _("note: ")+"((?!.*(candidate|"+qo+"|"+qc+")).*)$", "Cpp", "monokai" ],
+        # after the code part, to avoid matching ANSI escape chars
+        [ _("note: "), "green", "normal" ]
     ]
 
